StellarTransaction class

Constructors

StellarTransaction({required String id, required String hash, required String memo, required double amount, required String status, required String sourceAccount, required String destination, required String assetCode, required String assetIssuer, required DateTime createdAt, required DateTime processedAt, required String type})
StellarTransaction.fromJson(Map<String, dynamic> json)
factory

Properties

amount double
final
assetCode String
final
assetIssuer String
final
createdAt DateTime
final
destination String
final
hash String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
memo String
final
processedAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceAccount String
final
status String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited